==> lokinet-docs-v0.9.9.tar.xz: lokinet-docs-v0.9.9/markdown/Classes/classllarp_1_1quic_1_1Address.md <==
---
title: llarp::quic::Address

---

# llarp::quic::Address





## Public Functions

|                | Name           |
| -------------- | -------------- |
| | **[Address](Classes/classllarp_1_1quic_1_1Address.md#function-address)**() =default |
| | **[Address](Classes/classllarp_1_1quic_1_1Address.md#function-address)**(const [SockAddr](Classes/structllarp_1_1SockAddr.md) & addr) |
| | **[Address](Classes/classllarp_1_1quic_1_1Address.md#function-address)**(const [Address](Classes/classllarp_1_1quic_1_1Address.md) & other) |
| [Address](Classes/classllarp_1_1quic_1_1Address.md) & | **[operator=](Classes/classllarp_1_1quic_1_1Address.md#function-operator=)**(const [Address](Classes/classllarp_1_1quic_1_1Address.md) & ) |
| | **[operator sockaddr *](Classes/classllarp_1_1quic_1_1Address.md#function-operator-sockaddr-*)**() |
| | **[operator const sockaddr *](Classes/classllarp_1_1quic_1_1Address.md#function-operator-const-sockaddr-*)**() const |
| | **[operator ngtcp2_addr &](Classes/classllarp_1_1quic_1_1Address.md#function-operator-ngtcp2-addr-&)**() |
| | **[operator const ngtcp2_addr &](Classes/classllarp_1_1quic_1_1Address.md#function-operator-const-ngtcp2-addr-&)**() const |
| size_t | **[sockaddr_size](Classes/classllarp_1_1quic_1_1Address.md#function-sockaddr-size)**() const |
| | **[operator service::ConvoTag](Classes/classllarp_1_1quic_1_1Address.md#function-operator-serviceconvotag)**() const |
| [nuint16_t](Classes/structllarp_1_1nuint__t.md) | **[port](Classes/classllarp_1_1quic_1_1Address.md#function-port)**() const |
| void | **[port](Classes/classllarp_1_1quic_1_1Address.md#function-port)**([nuint16_t](Classes/structllarp_1_1nuint__t.md) port) |
| | **[operator SockAddr](Classes/classllarp_1_1quic_1_1Address.md#function-operator-sockaddr)**() const |
| std::string | **[to_string](Classes/classllarp_1_1quic_1_1Address.md#function-to-string)**() const |

## Public Functions Documentation

### function Address

```cpp
Address() =default
```


### function Address

```cpp
Address(
    const SockAddr & addr
)
```


### function Address

```cpp
inline Address(
    const Address & other
)
```


### function operator=

```cpp
Address & operator=(
    const Address & 
)
```


### function operator sockaddr *

```cpp
inline operator sockaddr *()
```


### function operator const sockaddr *

```cpp
inline operator const sockaddr *() const
```


### function operator ngtcp2_addr &

```cpp
inline operator ngtcp2_addr &()
```


### function operator const ngtcp2_addr &

```cpp
inline operator const ngtcp2_addr &() const
```


### function sockaddr_size

```cpp
inline size_t sockaddr_size() const
```


### function operator service::ConvoTag

```cpp
operator service::ConvoTag() const
```


### function port

```cpp
inline nuint16_t port() const
```


### function port

```cpp
inline void port(
    nuint16_t port
)
```


### function operator SockAddr

```cpp
inline operator SockAddr() const
```


### function to_string

```cpp
std::string to_string() const
```


-------------------------------

Updated on 2022-05-31 at 02:25:20 +0000

==> lokinet-docs-v0.9.11.tar.xz: lokinet-docs-v0.9.11/markdown/Classes/classllarp_1_1quic_1_1Address.md <==
---
title: llarp::quic::Address

---

# llarp::quic::Address





## Public Functions

|                | Name           |
| -------------- | -------------- |
| | **[Address](Classes/classllarp_1_1quic_1_1Address.md#function-address)**() =default |
| | **[Address](Classes/classllarp_1_1quic_1_1Address.md#function-address)**(const [SockAddr](Classes/structllarp_1_1SockAddr.md) & addr) |
| | **[Address](Classes/classllarp_1_1quic_1_1Address.md#function-address)**(const [Address](Classes/classllarp_1_1quic_1_1Address.md) & other) |
| [Address](Classes/classllarp_1_1quic_1_1Address.md) & | **[operator=](Classes/classllarp_1_1quic_1_1Address.md#function-operator=)**(const [Address](Classes/classllarp_1_1quic_1_1Address.md) & ) |
| template <typename T ,std::enable_if_t< std::is_same_v< T, sockaddr >, int >  =0\> <br>| **[operator T*](Classes/classllarp_1_1quic_1_1Address.md#function-operator-t*)**() |
| template <typename T ,std::enable_if_t< std::is_same_v< T, sockaddr >, int >  =0\> <br>| **[operator const T *](Classes/classllarp_1_1quic_1_1Address.md#function-operator-const-t-*)**() const |
| | **[operator ngtcp2_addr &](Classes/classllarp_1_1quic_1_1Address.md#function-operator-ngtcp2-addr-&)**() |
| | **[operator const ngtcp2_addr &](Classes/classllarp_1_1quic_1_1Address.md#function-operator-const-ngtcp2-addr-&)**() const |
| size_t | **[sockaddr_size](Classes/classllarp_1_1quic_1_1Address.md#function-sockaddr-size)**() const |
| | **[operator service::ConvoTag](Classes/classllarp_1_1quic_1_1Address.md#function-operator-serviceconvotag)**() const |
| nuint16_t | **[port](Classes/classllarp_1_1quic_1_1Address.md#function-port)**() const |
| void | **[port](Classes/classllarp_1_1quic_1_1Address.md#function-port)**(nuint16_t port) |
| | **[operator SockAddr](Classes/classllarp_1_1quic_1_1Address.md#function-operator-sockaddr)**() const |
| std::string | **[ToString](Classes/classllarp_1_1quic_1_1Address.md#function-tostring)**() const |

## Public Functions Documentation

### function Address

```cpp
Address() =default
```


### function Address

```cpp
Address(
    const SockAddr & addr
)
```


### function Address

```cpp
inline Address(
    const Address & other
)
```


### function operator=

```cpp
Address & operator=(
    const Address & 
)
```


### function operator T*

```cpp
template <typename T ,
std::enable_if_t< std::is_same_v< T, sockaddr >, int >  =0>
inline operator T*()
```


### function operator const T *

```cpp
template <typename T ,
std::enable_if_t< std::is_same_v< T, sockaddr >, int >  =0>
inline operator const T *() const
```


### function operator ngtcp2_addr &

```cpp
inline operator ngtcp2_addr &()
```


### function operator const ngtcp2_addr &

```cpp
inline operator const ngtcp2_addr &() const
```


### function sockaddr_size

```cpp
inline size_t sockaddr_size() const
```


### function operator service::ConvoTag

```cpp
operator service::ConvoTag() const
```


### function port

```cpp
inline nuint16_t port() const
```


### function port

```cpp
inline void port(
    nuint16_t port
)
```


### function operator SockAddr

```cpp
inline operator SockAddr() const
```


### function ToString

```cpp
std::string ToString() const
```


-------------------------------

Updated on 2022-11-29 at 18:11:26 +0000
